California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images | Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 GENERAL Prior Elections 2022 PRIMARY 2022 SPECIAL ELECTION (ASSEMBLY 11) 2022 SPECIAL ELECTION (ASSEMBLY 80) 2022 SPECIAL ELECTION (ASSEMBLY 62) 2022 SPECIAL ELECTION (ASSEMBLY 17) 2022 SPECIAL ELECTION (ASSEMBLY 49) 2021 SPECIAL ELECTION (GOVERNOR) 2021 SPECIAL ELECTION (ASSEMBLY 18) 2021 SPECIAL ELECTION (ASSEMBLY 54) 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 21) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
ANDERSON, RONALD A. BHANGOO, GURINDER S COLLINS, HEATHER COLLINS, SHAWN DAHLE, BRIAN FANARA, ANTHONY L. FIANKAN, SERGE HANINK, JAMES G JONES, RONALD E. LE ROUX, JENNY RAE LOZANO, DAVID MERCURI, DANIEL R. MORALES, CRISTIAN R. NEWMAN II, ROBERT C. NEWSOM, GAVIN PEREZ-SERRATO, ARMANDO RODRIGUEZ, LUIS J. SANDERS III, WOODROW SCHULTZ, FREDERIC C. SCOTT, JEFF SENUM, REINETTE SHELLENBERGER, MICHAEL D. SORTOR, LONNIE L. TRIMINO, ANTHONY D VENTRESCA, JOEL A. WILLIAMS, MAJOR ZACKY, LEO S. ZINK, WILLIAM B.
| LIEUTENANT GOVERNOR
ARIF, MOHAMMAD FENNELL, DAVID D. HILLBERG, DAVID A. KOUNALAKIS, ELENI MORGAN, JEFFREY HIGHBEAR OGLE, JAMES O. SAACKE, WILLIAM C. SAUNDERS, CLINT W. UNDERWOOD JACOBS, ANGELA E.
SECRETARY OF STATE
BERNOSKY, ROBERT E. BLENNER, GARY N. CINQUANTA, MATTHEW D. HAMM, RACHEL PAINE, JAMES W. RODRIGUEZ JR., RAUL SILVEIRA, DESMOND A. WEBER, SHIRLEY
| CONTROLLER
CHEN, LANHEE J. COHEN, MALIA M. GALPERIN, RON GLAZER, STEVEN WELLS, LAURA YIU, YVONNE
TREASURER
ADAMS, MEGHANN L DO, ANDREW GUERRERO, JACK M. MA, FIONA
| ATTORNEY GENERAL
BONTA, ROB EARLY, ERIC P. HOCHMAN, NATHAN KAPELOVITZ, DAN SCHUBERT, ANNE MARIE
SUPERINTENDENT OF PUBLIC INSTRUCTION
AMARAL, MARCO CAMPBELL, JOSEPH GUY CHRISTENSEN, LANCE GIBSON, JAMES E. LONG, AINYE E. THURMOND, TONY YANG, GEORGE
| INSURANCE COMMISSIONER
ALLEN, VINSON EUGENE CONLON, GREG FIMBRES, VERONIKA HOWELL, ROBERT P. HRIZI, NATHALIE JACKSON, JASPER J. LARA, RICARDO LEVINE, MARC MOLNAR, ROBERT J.
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
ALTAMIRANO, JOSE S. GAINES, EDWARD MOORE MURPHY, BRADEN D SHAHATIT, NADER F
| MEMBER BOARD OF EQUALIZATION 02
ALIOTO-PIER, MICHELA LIEBER, SALLY VERBICA, PETER C.
MEMBER BOARD OF EQUALIZATION 03
MANVEL, YANA M. MARSHALL, GLENN R. MENDOZA, JOHN VAZQUEZ, ANTONIO
| MEMBER BOARD OF EQUALIZATION 04
BILODEAU, DENIS R. DODSON, DAVID B. ECONOMY, RANDELL R. HARPER, MATTHEW KELLY, JOHN F PETERSON, ERIK SCHAEFER, J. MICHAEL
SENATE DISTRICTS
STATE SENATE 02
MC GUIRE, MIKE YOON, GINSU 'GENE'
| STATE SENATE 04
ALVARADO-GIL, MARIE I. BAILEY, STEVEN DALY, JOLENE GORDON, MICHAEL GRIFFITH, JACK A. MC KAY, JEFFREY D. RADANOVICH, GEORGE ROBERTSON, TIMOTHY W.
STATE SENATE 06
HUANG, MICHAEL J. NIELLO, ROGER VILLESCAZ, PAULA
| STATE SENATE 08
ASHBY, ANGELIQUE GARCIA JR., RAFAEL JONES, DAVE MASON, SUSAN
STATE SENATE 10
CANOVA, JIM (JAMES D.) KHAN, JAMAL H. LIU, RAYMOND MEI, LILY PIMENTEL, PAUL J. WAHAB, AISHA
| STATE SENATE 12
GROVE, SHANNON GUNDY, SUSANNE
STATE SENATE 14
CABALLERO, ANNA MIRANDA, PAULINA M. SHOR, AMNON
| STATE SENATE 16
HURTADO, MELISSA OSORIO, BRYAN PARRA, NICOLE SHEPARD, DAVID E TATUM, GREGORY
STATE SENATE 18
GALICIA, ALEJANDRO PADILLA, STEVE
| STATE SENATE 20
AYAO, ELY DE LA CRUZ HERTZBERG, DANIEL MENJIVAR, CAROLINE MORALES, SEYDI ALEJANDRA
STATE SENATE 22
MATEO, KIMO RUBIO, SUSAN TSAI, VINCENT
| STATE SENATE 24
ALLEN, BEN DUTERTE, EDWIN P IRWIN, KRISTINA
STATE SENATE 26
AGRAZ, CLAUDIA DURAZO, MARIA ELENA
| STATE SENATE 28
GULLEDGE, JAMAAL A. LISUZZO, JOSEPH MOORE, KAMILAH VICTORIA SMALLWOOD-CUEVAS, LOLA TURNER, CHERYL C.
STATE SENATE 30
ARCHULETA, BOB BOUCHOT, HENRY CAMACHO RODRIGUEZ, MARTHA CLEMMONS, MITCH
| STATE SENATE 32
NASH, BRIAN SEYARTO, KELLY
STATE SENATE 34
SHADER, RHONDA UMBERG, THOMAS J.
| STATE SENATE 36
CARR, KIM NGUYEN, JANET
STATE SENATE 38
BLAKESPEAR, CATHERINE GUNDERSON, MATTHEW KERR, JOE
| STATE SENATE 40
JONES, BRIAN W. ROCHA, JOSEPH
ASSEMBLY DISTRICTS
ASSEMBLY 01
BROWN, JOSHUA D. DAHLE, MEGAN SANDWITH, BELLE STARR TANNER, KELLY WILLETT
| ASSEMBLY 02
SVOLOS, CHARLOTTE WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES HOSTON, JEANENNE H. ZINK, DAVID LEON
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA PELICAN, SUSAN PRITCHARD, BRYAN T.
ASSEMBLY 05
CHENOWETH, REBECCA L. PALETTA, JASON PATTERSON, JOE SMITH, GREG S.
| ASSEMBLY 06
BONSER, JANICE M. COOK, CATHERINE M. MARQUES, ROBERT "BOB" C. MC CARTY, KEVIN PANE, JOSH
ASSEMBLY 07
COOLEY, KEN HOOVER, JOSH LEVESQUE, QUINTIN TOSHI PERRINE, JEFFREY E. RIEHLE, RAYMOND A.
| ASSEMBLY 08
NICHOLS, THOMAS E PATTERSON, JIM
ASSEMBLY 09
FLORA, HEATH TAHIRKHELI, MUSHTAQ A.
| ASSEMBLY 10
GUERRA, ERIC NGUYEN, STEPHANIE PORTER, TECOY RIGARD, ERIC THOMPKINS, BENNIE
ASSEMBLY 11
BERG, JAMES CALLISON, JENNY L. WILSON, LORI
| ASSEMBLY 12
AMINZADEH, SARA CONNOLLY, DAMON PODSHADLEY, ANDREW ALAN SCHWARTZ, STEVE TIMES-GREEN, IDA
ASSEMBLY 13
BEDOLLA, MATEO M. VARGAS, VERONICA VILLAPUDUA, CARLOS WAGNER, JESSICA
| ASSEMBLY 14
KINNEY, RICHARD WICKS, BUFFY
ASSEMBLY 15
GRAYSON, TIM PROCTOR, JANELL
| ASSEMBLY 16
BAUER-KAHAN, REBECCA RUBAY, JOSEPH A.
ASSEMBLY 17
CAMPOS, DAVID F. HANEY, MATT SHIREMAN, WILLIAM K.
| ASSEMBLY 18
BONTA, MIA PECHENUK, MINDY
ASSEMBLY 19
TING, PHIL WEIDE, KARSTEN
| ASSEMBLY 20
ESTEEN, JENNIFER GRCAR, JOSEPH KUMAGAI, SHAWN ORTEGA-TORO, LIZ
ASSEMBLY 21
COLEMAN, JAMES HSUCHEN GILHAM, MARK GOODMAN, MAURICE D. HALE, GISELLE MADDEN, ALISON PAPAN, DIANE SOLE, TANIA
| ASSEMBLY 22
ALANIS, JUAN CAMPOS, JOEL G. CONDIT, CHAD SALAZAR, GUADALUPE 'LUPITA' SELF, JESSICA S.
ASSEMBLY 23
BERMAN, MARC E. DEC, TIM
| ASSEMBLY 24
BRUNTON, ROBERT L. CHU, KANSEN DIEP, LAN KENG, TERESA C. LEE, ALEX T.
ASSEMBLY 25
KALRA, ASH STROLL, THEODORE J.
| ASSEMBLY 26
GORSULOWSKY, TIM S. JIAO, LONG LOW, EVAN
ASSEMBLY 27
FLEMING, AMANDA KARBASSI, KIA M. PAZIN, MARK N. PELLISSIER, RANDALL COREY SORIA, ESMERALDA
| ASSEMBLY 28
LAWLER, LIZ PELLERIN, GAIL RENNIE, ROBERT L. THOMPSON, JOSEPH M.
ASSEMBLY 29
CASTRO, STEPHANIE L. RIVAS, ROBERT
| ASSEMBLY 30
ADDIS, DAWN J. CARTER, ZOE DRAKE, JOHN R. NOHRDEN, VICKI L. WIZARD, JON
ASSEMBLY 31
ARAMBULA, JOAQUIN CALANDRA, DOLCE M. MENDOZA, JOHN C. VERHINES, ANDREW W.
| ASSEMBLY 32
FONG, VINCENT
ASSEMBLY 33
MACARENO, RUBEN MATHIS, DEVON J. SIGALA, JOSE
| ASSEMBLY 34
FOURNIER, PAUL KAHLON, RAJ LA PLANTE, ROGER A. LACKEY, THOMAS W. RAMIREZ-DEAN, RITA SMITH, THURSTON
ASSEMBLY 35
BAINS, JASMEET PEREZ, LETICIA
| ASSEMBLY 36
GARCIA, EDUARDO WARE, MARLON G. WEEKS, IAN MICHAEL
ASSEMBLY 37
HART, GREGG A, STOKER, MIKE WALLACH, BRUCE J.
| ASSEMBLY 38
BENNETT, STEPHEN A. BROCATO, COLE C. WILSON, DANIEL L.
ASSEMBLY 39
CARRILLO, JUAN FOX, STEVE MARSH, PAUL A. ROSENTHAL, ANDREA
| ASSEMBLY 40
CHO, ANNIE E. SCHIAVO, PILAR VALLADARES, SUZETTE M.
ASSEMBLY 41
HOLDEN, CHRIS MC MAHON, MICHAEL B.
| ASSEMBLY 42
IRWIN, JACQUI V. MILLS, LORI NORDBLUM, THEODORE KENNETH
ASSEMBLY 43
MASSAQUOI, SIAKA RIVAS, LUZ
| ASSEMBLY 44
FRIEDMAN, LAURA JACOBSEN, BARRY CURTIS
ASSEMBLY 45
MARTINEZ, JOSEPH W. RAMOS, JAMES
| ASSEMBLY 46
CARUSO, DANA FRANCES GABRIEL, JESSE
ASSEMBLY 47
HOLSTEGE, CHRISTY MICHAELS, GARY J. SWAIN, JAMIE L WALLIS, GREG
| ASSEMBLY 48
MAYE, RYAN RUBIO, BLANCA
ASSEMBLY 49
BRINK, BURTON FONG, MICHAEL
| ASSEMBLY 50
COHEN, RODGIR REYES, ELOISE GOMEZ STARK, SHEELA
ASSEMBLY 51
ABRAMSON, LOUIS E. ZBUR, RICK CHAVEZ
| ASSEMBLY 52
CARRILLO, WENDY D'AMATO, GIANNINA M LIVAS PORTER, MIA
ASSEMBLY 53
HOLLE, TONI M. RODRIGUEZ, FREDDIE
| ASSEMBLY 54
ALANIZ, ELAINE SANTIAGO, MIGUEL
ASSEMBLY 55
BRYAN, ISAAC CASCIO, KEITH G.
| ASSEMBLY 56
CALDERON, LISA MARTINEZ, JESSICA SERRANO, NATASHA
ASSEMBLY 57
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 58
CASTILLO, LETICIA CERVANTES, SABRINA MURPHY, BERNARD WILLIAM
ASSEMBLY 59
CHEN, PHILLIP NARANJO, DAVID SIT, LEON Q.
| ASSEMBLY 60
DIAZ NAVA, HECTOR JACKSON, COREY A. PORTILLO, ESTHER RUBIO, JASMIN Z.
ASSEMBLY 61
MC KINNOR, TINA PULLEN-MILES, ROBERT REYES ENGLISH, ANGIE RUDERMAN, NICO SPENCER, JAMES A.
| ASSEMBLY 62
ESTRADA, MARIA RENDON, ANTHONY
ASSEMBLY 63
ESSAYLI, BILL LORIMORE, CLINT RIZVI, FAUZIA
| ASSEMBLY 64
ALCANTAR, ELIZABETH CANCIO, ROBERT ESPINOZA, ROSE ORTIZ JR., RAUL PACHECO, BLANCA VALENCIA, ANA
ASSEMBLY 65
GIPSON, MIKE GUTIERREZ, LYDIA A. IQBAL-ZUBAIR, FATIMA S.
| ASSEMBLY 66
BARKS, GEORGE G. MURATSUCHI, AL
ASSEMBLY 67
BRAR, PARAMVIR S. MOUA, SOU QUIRK-SILVA, SHARON YOO, SOO
| ASSEMBLY 68
TARDIF, MIKE VALENCIA, AVELINO VICENTE, BULMARO 'BOOMER' WALLACE, JAMES TODD
ASSEMBLY 69
AUSTIN, ALVIN R. FOSTER, JANET LOWENTHAL, JOSH TAHERI, MERRY
| ASSEMBLY 70
BUI, TED GRAY, JASON A. HIBARD, EMILY V. HO, KIMBERLY TA, TRI THU-HA NGUYEN, DIEDRE
ASSEMBLY 71
MILLER, ALBIA RAHN, MATTHEW SANCHEZ, KATHRYN
| ASSEMBLY 72
DIXON, DIANE MANCUSO, JUDIE YU, BENJAMIN
ASSEMBLY 73
CHOI, STEVEN PETRIE-NORRIS, COTTIE
| ASSEMBLY 74
DAVIES, LAURIE A. DUNCAN, CHRIS
ASSEMBLY 75
VOEPEL, RANDY G. WALDRON, MARIE
| ASSEMBLY 76
BRUCE-LANE, KRISTIE CUTTER, JUNE YANG MAIENSCHEIN, BRIAN
ASSEMBLY 77
BOERNER HORVATH, TASHA DOWNEY, DANIEL F.
| ASSEMBLY 78
GONZALES, ERIC E. WARD, CHRISTOPHER M.
ASSEMBLY 79
MOORE, JOHN S. SABOL, CORBIN A. WEBER, AKILAH
| ASSEMBLY 80
ALVAREZ, DAVID GOMEZ, GEORGETTE PICKARD, LINCOLN VOGEL GARCIA, JOHN J.